{ TAMTrBmp version 1.0 copyright  may 1997 by Alexander Meeder (ameeder@dds.nl)

  This is a really transparent bitmap component. You can choose one color of an original *.BMP file.
  This color is'nt just replace with another color (as with the canvasses BrushCopy-function) but
  the picture is real transparent.

  This version is for Delphi 1.x and Delphi 2.x
}

unit AMTrBmp;

interface

uses
  {$IFDEF WIN32}
    Windows,
  {$ELSE}
    WinTypes, WinProcs,
  {$ENDIF}
    Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs;

type
  TAMTrBmp = class(TGraphicControl)
  private
    FImageList: TImageList;
    FPicture: TBitmap;
    FTransparentColor: TColor;

    procedure SetPicture(value: TBitmap);
    procedure SetTransparentColor(value: TColor);
  protected
    procedure Paint; override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    property Picture: TBitmap read FPicture write SetPicture;
    property TransparentColor: TColor read FTransparentColor write SetTransparentColor;
  end;

procedure Register;

implementation

procedure TAMTrBmp.Paint;
var
  PictureIndex: integer;
begin
  canvas.brush.style := bsClear;
  if FPicture.Empty then Exit;
  {$IFDEF WIN32}
     FImageList := TImageList.CreateSize(FPicture.Width, FPicture.Height);
  {$ELSE}
     FImageList := TImageList.Create(FPicture.Width, FPicture.Height);
  {$ENDIF}
  try
    PictureIndex := FImageList.AddMasked(FPicture, FTransparentColor);
    FImageList.Draw(Canvas, 0, 0, PictureIndex);
  finally
    FImageList.Free;
  end;
end;

procedure TAMTrBmp.SetPicture(value: TBitmap);
begin
  if value <> FPicture then
  begin
    FPicture.Assign(value);
    if value <> nil then
    begin
      SetBounds(0, 0, FPicture.Width, FPicture.Height);
      FTransparentColor := FPicture.Canvas.Pixels[0, FPicture.Height - 1];
    end;
  end;
  Refresh;
end;

procedure TAMTrBmp.SetTransparentColor(value: TColor);
begin
  if not (FPicture.Empty) and (value <> FTransparentColor) then
  begin
    FTransparentColor := value;
    Invalidate;
  end;
end;

constructor TAMTrBmp.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  if not (csDesigning in ComponentState) then ControlStyle := ControlStyle + [csOpaque];
  SetBounds(0, 0, 105, 105);
  FPicture := TBitmap.Create;
end;

destructor TAMTrBmp.Destroy;
begin
  FPicture.Free;
  inherited Destroy;
end;

procedure Register;
begin
  RegisterComponents('AM Controls', [TAMTrBmp]);
end;

end.
